<?php
/**
 * Ngo_Charity Footer Settings panel at Theme Customizer
 *
 * @package Ngo_Charity
 * @since 1.0.0
 */

add_action( 'customize_register', 'ngo_charity_footer_settings_register' );

function ngo_charity_footer_settings_register( $wp_customize ) {
  require get_template_directory() .'/inc/repeater/class-repeater-settings.php';
  require get_template_directory() .'/inc/repeater/class-control-repeater.php';

	/**
     * Add Footer Settings Panel
     *
     * @since 1.0.0
     */
  $wp_customize->add_panel(
   'ngo_charity_footer_settings_panel',
   array(
     'priority'       => 30,
     'capability'     => 'edit_theme_options',
     'theme_supports' => '',
     'title'          => __( 'Footer Settings', 'ngo-charity-pro' ),
   )
 );

  /*----------------------------------------------------------------------------------------------------------------------------------------*/
  /**
     * Footer top section
     *
     * @since 1.0.0
     */
  $wp_customize->add_section(
    'ngo_charity_footer_top_section',
    array(
      'priority'       => 1,
      'panel'          => 'ngo_charity_footer_settings_panel',
      'capability'     => 'edit_theme_options',
      'theme_supports' => '',
      'title'          => __( 'Footer Top Section', 'ngo-charity-pro' ),
      'description'    => __( 'Managed the content display at Footer Top section.', 'ngo-charity-pro' ),
    )
  );

 /**
 * Enable/Disable for footer top
 *
 * @since 1.0.0
 */
 $wp_customize->add_setting(
  'ngo_charity_footer_top_enable',
  array(
    'default'           => 0,
    'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
  )
);

 $wp_customize->add_control(
  'ngo_charity_footer_top_enable',
  array(
    'section'     => 'ngo_charity_footer_top_section',
    'label'       => __( 'Enable/Disable for Footer Top Newsletter', 'ngo-charity-pro' ),
    'type'        => 'checkbox'
  )       
);

// Newsletter Title
 $wp_customize->add_setting('ngo_charity_footer_top_newsletter_title',array(
  'default'       =>      '',
  'sanitize_callback'     =>  'sanitize_text_field'
));

 $wp_customize->add_control('ngo_charity_footer_top_newsletter_title',array(
  'section'       =>      'ngo_charity_footer_top_section',
  'label'         =>      __('Newsletter Title', 'ngo-charity-pro'),
  'description'   =>      __('Eg:- Sign Up For newsletter', 'ngo-charity-pro'),
  'type'          =>      'text',
  'settings'    =>    'ngo_charity_footer_top_newsletter_title'
));


// Newsletter Description
 $wp_customize->add_setting('ngo_charity_footer_top_newsletter_description',array(
  'default'       =>      '',
  'sanitize_callback'     =>  'sanitize_text_field'
));

 $wp_customize->add_control('ngo_charity_footer_top_newsletter_description',array(
  'section'       =>      'ngo_charity_footer_top_section',
  'label'         =>      __('Newsletter Description', 'ngo-charity-pro'),
  'description'   =>      __('Eg:- Submit your email and stay in touch by notify our news & update regularly', 'ngo-charity-pro'),
  'type'          =>      'text',
  'settings'    =>    'ngo_charity_footer_top_newsletter_description'
));


// Newsletter Form Shortcode Descriptions
 $wp_customize->add_setting('ngo_charity_top_header_newsletter_shortcode',array(
  'default'       =>      '',
  'sanitize_callback'     =>  'sanitize_text_field'
));
 $wp_customize->add_control('ngo_charity_top_header_newsletter_shortcode',array(
  'section'       =>      'ngo_charity_footer_top_section',
  'label'                 =>  __( 'Use Shortcode for newsletter form', 'ngo-charity-pro' ),
  /* translators: %s: Description */ 
  'description'           => sprintf( __( 'Use Newsletter Plugins shortcode: Eg: %1$s. %2$s See more here %3$s', 'ngo-charity-pro' ), '[newsletter_form type="minimal"]','<a href="'.esc_url('https://wordpress.org/plugins/newsletter/').'" target="_blank">','</a>' ),
  'type'          =>      'text',
  'settings'    =>    'ngo_charity_top_header_newsletter_shortcode'
));


 /*----------------------------------------------------------------------------------------------------------------------------------------*/
  /**
     * Footer Middle section
     *
     * @since 1.0.0
     */
  $wp_customize->add_section(
    'ngo_charity_footer_middle_section',
    array(
      'priority'       => 2,
      'panel'          => 'ngo_charity_footer_settings_panel',
      'capability'     => 'edit_theme_options',
      'theme_supports' => '',
      'title'          => __( 'Footer Middle Section', 'ngo-charity-pro' ),
      'description'    => __( 'Managed the content display at Footer Middle section.', 'ngo-charity-pro' ),
    )
  );

 /**
 * Enable/Disable for Footer Middle section
 *
 * @since 1.0.0
 */
 $wp_customize->add_setting(
  'ngo_charity_volunteer_enable',
  array(
    'default'           => 0,
    'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
  )
);

 class Widget_Page_link extends WP_Customize_Control {
  public $type = 'customtext';
    public $extra = ''; // we add this for the extra description
    public function render_content() {
      ?>
      <label>            
        <a href="<?php echo esc_url( 'widgets.php' ); ?>" target='_blank'><?php echo esc_html( $this->label ); ?></a>
        <span><?php echo esc_html( $this->extra ); ?></span>         
      </label>
      <?php
    }
  }
  $wp_customize->add_setting('ngo_charity_go_to_widget', array(
    'default' => '',
    'type' => 'customtext',
    'capability' => 'edit_theme_options',
    'transport' => 'refresh',
    'sanitize_callback' => 'sanitize_text_field',
  ) );
  $wp_customize->add_control( new Widget_Page_link( $wp_customize, 'ngo_charity_go_to_widget', array(
    'label' => esc_attr__( 'Go to Widgets Page', 'ngo-charity-pro' ),
    'section' => 'ngo_charity_footer_middle_section',
    'settings' => 'ngo_charity_go_to_widget',
    'extra' => esc_attr__( 'click here', 'ngo-charity-pro' )
  ) ) 
);


  /*----------------------------------------------------------------------------------------------------------------------------------------*/
  /**
     * Footer Bottom section
     *
     * @since 1.0.0
     */
  $wp_customize->add_section(
    'ngo_charity_footer_bottom_section',
    array(
      'priority'       => 3,
      'panel'          => 'ngo_charity_footer_settings_panel',
      'capability'     => 'edit_theme_options',
      'theme_supports' => '',
      'title'          => __( 'Footer Bottom Section', 'ngo-charity-pro' ),
      'description'    => __( 'Managed the content display at Footer Bottom section.', 'ngo-charity-pro' ),
    )
  );

  /**Footer Copyright Text */
  $wp_customize->add_setting(
    'ngo_charity_footer_copyright_text',
    array(
      'default'           => __( 'Copyright &copy; 2018 MyWordPress Themes, Inc. All rights reserved.', 'ngo-charity-pro' ),
      'sanitize_callback' => 'sanitize_text_field',
      'transport'         => 'postMessage'
    )
  );

  $wp_customize->add_control(
    'ngo_charity_footer_copyright_text',
    array(
      'label'    => __( 'Footer Copyright text', 'ngo-charity-pro' ),
      'section'  => 'ngo_charity_footer_bottom_section',
      'type'     => 'text',
    )
  );

  $wp_customize->selective_refresh->add_partial( 'ngo_charity_footer_copyright_text', array(
    'selector' => 'footer .copyright .container p',
    'render_callback' => 'ngo_charity_footer_copyright_get_links_text',
  ) );
  
  /**Footer Social media  Enable/Disable  */
  $wp_customize->add_setting(
    'footer_social_media_enable',
    array(
      'default'           => 0,
      'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
    )
  );

  $wp_customize->add_control(
    'footer_social_media_enable',
    array(
      'section'     => 'ngo_charity_footer_bottom_section',
      'label'       => __( 'Social Links', 'ngo-charity-pro' ),
      'description' => __( 'Enable/Disable social links in Footer.', 'ngo-charity-pro' ),
      'type'        => 'checkbox'
    )       
  );


  /** Social Links */
  $wp_customize->add_setting( 
    new Ngo_Charity_Repeater_Setting( 
      $wp_customize, 
      'ngo_charity_social_links', 
      array(
        'default' => array(
          array(
            'font' => 'fa fa-facebook',
            'link' => 'https://www.facebook.com/',                        
          ),
          array(
            'font' => 'fa fa-linkedin',
            'link' => 'https://www.linkedin.com/',
          ),
          array(
            'font' => 'fa fa-twitter',
            'link' => 'https://twitter.com/',
          ),
          array(
            'font' => 'fa fa-google-plus',
            'link' => 'https://plus.google.com',
          )
        ),
        'sanitize_callback' => array( 'Ngo_Charity_Repeater_Setting', 'sanitize_repeater_setting' ),
      ) 
    ) 
  );

  $wp_customize->add_control(
    new Ngo_Charity_Control_Repeater(
      $wp_customize,
      'ngo_charity_social_links',
      array(
        'section' => 'ngo_charity_footer_bottom_section',              
        'label'   => __( 'Social Links', 'ngo-charity-pro' ),
        'fields'  => array(
          'font' => array(
            'type'        => 'font',
            'label'       => __( 'Font Awesome Icon', 'ngo-charity-pro' ),
            'description' => __( 'Example: fa-facebook', 'ngo-charity-pro' ),
          ),
          'link' => array(
            'type'        => 'url',
            'label'       => __( 'Link', 'ngo-charity-pro' ),
            'description' => __( 'Example: http://facebook.com', 'ngo-charity-pro' ),
          )
        ),
        'row_label' => array(
          'type' => 'field',
          'value' => __( 'social', 'ngo-charity-pro' ),
          'field' => 'link'
        )                        
      )
    )
  );
}