<?php

/**
 * Social_Charity Frontpage Settings panel at Theme Customizer
 *
 * @package Social_Charity
 * @since 1.0.0
 */
add_action( 'customize_register', 'ngo_charity_frontpage_settings_register' );

function ngo_charity_frontpage_settings_register( $wp_customize ) {
 require get_template_directory() .'/inc/repeater/class-repeater-settings.php';
 require get_template_directory() .'/inc/repeater/class-control-repeater.php';
/**
 * Add Frontpage Settings Panel
 *
 * @since 1.0.0
 */
$wp_customize->add_panel(
  'ngo_charity_frontpage_settings_panel',
  array(
    'priority'       => 15,
    'capability'     => 'edit_theme_options',
    'theme_supports' => '',
    'title'          => __( 'Frontpage Settings', 'social-charity-pro' ),
  )
);

/*----------------------------------------------------------------------------------------------------------------------------------------*/
/**
 * Front page slider section
 *
 * @since 1.0.0
 */

$wp_customize->add_section(
  'ngo_charity_frontpage_slider_section',
  array(
   'priority'       => 1,
   'panel'          => 'ngo_charity_frontpage_settings_panel',
   'capability'     => 'edit_theme_options',
   'theme_supports' => '',
   'title'          => __( 'Slider Section', 'social-charity-pro' ),
   'description'    => __( 'Managed the slider display at Frontpage section.', 'social-charity-pro' ),
 )
);

/**
 * Enable/Disable for  Slider
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
  'ngo_charity_slider_enable',
  array(
    'default'           => 0,
    'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
  )
);

$wp_customize->add_control(
  'ngo_charity_slider_enable',
  array(
    'section'     => 'ngo_charity_frontpage_slider_section',
    'label'       => __( 'Enable/Disable for  Slider', 'social-charity-pro' ),
    'type'        => 'checkbox'
  )       
);

/*
* Banner slider section
*/
for ($i=1;$i<=11;$i++) {
// Select Page For Slider title with featured image.
  $wp_customize->add_setting( 'ngo_charity_slider_title_'.$i, array(
    'capability'            => 'edit_theme_options',
    'default'               => '',
    'sanitize_callback'     => 'ngo_charity_sanitize_dropdown_pages'
  ) );

  $wp_customize->add_control('ngo_charity_slider_title_'.$i,
    array(
      /* translators: %s: Slider Number. */
      'label'                 =>  sprintf( __( 'Select Page for Slider %s title with featured image', 'social-charity-pro' ), $i ),
      'section' => 'ngo_charity_frontpage_slider_section',
      'type'=> 'dropdown-pages',
      'settings' => 'ngo_charity_slider_title_'.$i
    )
  );

  $wp_customize->add_setting( 'ngo_charity_slider_button_1_title_'.$i, array(
    'capability'            => 'edit_theme_options',
    'default'               => '',
    'sanitize_callback'     => 'sanitize_text_field'
  ) );

  $wp_customize->add_control( 'ngo_charity_slider_button_1_title_'.$i, array(
    /* translators: %s: Description */ 
    'label'                 =>  sprintf( __( 'First Button Title For Slider %s', 'social-charity-pro' ), $i ),
    'description'           =>  __( 'Join with Us', 'social-charity-pro' ),
    'section'               => 'ngo_charity_frontpage_slider_section',
    'type'                  => 'text',
    'settings' => 'ngo_charity_slider_button_1_title_'.$i,
  ) );

  $wp_customize->add_setting( 'ngo_charity_slider_button_1_url_'.$i, array(
    'capability'            => 'edit_theme_options',
    'default'               => '',
    'sanitize_callback'     => 'esc_url_raw'
  ) );

  $wp_customize->add_control( 'ngo_charity_slider_button_1_url_'.$i, array(
    /* translators: %s: Description */ 
    'label'                 =>  sprintf( __( 'Select URL For button Title 1 of slider  %s', 'social-charity-pro' ), $i ),
    'description'           =>  __( '#', 'social-charity-pro' ),
    'section'               => 'ngo_charity_frontpage_slider_section',
    'type'                  => 'url',
    'settings' => 'ngo_charity_slider_button_1_url_'.$i,
  ) );
}
/*----------------------------------------------------------------------------------------------------------------------------------------*/
/**
 * Front page Service section
 *
 * @since 1.0.0
 */

$wp_customize->add_section(
  'ngo_charity_frontpage_service_section',
  array(
    'priority'       => 2,
    'panel'          => 'ngo_charity_frontpage_settings_panel',
    'capability'     => 'edit_theme_options',
    'theme_supports' => '',
    'title'          => __( 'Service Section', 'social-charity-pro' ),
    'description'    => __( 'Managed the Service display at Frontpage section.', 'social-charity-pro' ),
  )
);

/**
 * Enable/Disable for service
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
  'ngo_charity_service_enable',
  array(
    'default'           => 0,
    'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
  )
);

$wp_customize->add_control(
  'ngo_charity_service_enable',
  array(
    'section'     => 'ngo_charity_frontpage_service_section',
    'label'       => __( 'Enable/Disable for service', 'social-charity-pro' ),
    'type'        => 'checkbox'
  )       
);

$wp_customize->add_setting('service_post_type_info', array(
  'default' => '',
  'type' => 'customtext',
  'capability' => 'edit_theme_options',
  'transport' => 'refresh',
  'sanitize_callback' => 'sanitize_text_field',
) );
$wp_customize->add_control( new Custom_Post_Type_Info( $wp_customize, 'service_post_type_info', array(
  'label' => esc_attr__( 'Go to Service Page', 'social-charity-pro' ),
  'section' => 'ngo_charity_frontpage_service_section',
  'settings' => 'service_post_type_info',
  'link'    => 'service',
  'extra' => esc_attr__( ' for more info', 'social-charity-pro' )
) ) 
);

/*----------------------------------------------------------------------------------------------------------------------------------------*/
/**
 * Front page Our Causes section
 *
 * @since 1.0.0
 */

$wp_customize->add_section(
  'ngo_charity_frontpage_our_causes_section',
  array(
   'priority'       => 3,
   'panel'          => 'ngo_charity_frontpage_settings_panel',
   'capability'     => 'edit_theme_options',
   'theme_supports' => '',
   'title'          => __( 'Our Causes Section', 'social-charity-pro' ),
   'description'    => __( 'Managed the Our Causes display at Frontpage section.', 'social-charity-pro' ),
 )
);

/**
 * Enable/Disable for Our Causes
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
  'ngo_charity_causes_enable',
  array(
    'default'           => 0,
    'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
  )
);

$wp_customize->add_control(
  'ngo_charity_causes_enable',
  array(
    'section'     => 'ngo_charity_frontpage_our_causes_section',
    'label'       => __( 'Enable/Disable for  Our Causes', 'social-charity-pro' ),
    'type'        => 'checkbox'
  )       
);


/** Causes Text */
$wp_customize->add_setting(
  'ngo_charity_causes_text',
  array(
    'default'           => __( 'Our Causes', 'social-charity-pro' ),
    'sanitize_callback' => 'sanitize_text_field',
    'transport'         => 'postMessage'
  )
);

$wp_customize->add_control(
  'ngo_charity_causes_text',
  array(
    'label'    => __( 'Causes Heading', 'social-charity-pro' ),
    'section'  => 'ngo_charity_frontpage_our_causes_section',
    'type'     => 'text',
  )
);

$wp_customize->selective_refresh->add_partial( 'ngo_charity_causes_text', array(
  'selector' => '.causes main-title h2',
  'render_callback' => 'ngo_charity_get_causes_text',
) );


$wp_customize->add_setting( 'ngo_charity_causes_number', array(
  'capability'            => 'edit_theme_options',
  'default'               => '3',
  'sanitize_callback'     => 'absint'
));

$wp_customize->add_control( 'ngo_charity_causes_number', array(
  'label'                 =>  __( 'Number of Recent Causes to Show in Front Page', 'social-charity-pro' ),
  'description'           =>  __( 'input 3,4,5,6,7,8,9,10', 'social-charity-pro' ),
  'section'               => 'ngo_charity_frontpage_our_causes_section',
  'type'                  => 'number',
  'settings' => 'ngo_charity_causes_number',
) );

if(check_wp_give_plugin_activation()):

$wp_customize->add_setting('ngo_charity_go_to_give_form', array(
  'default' => '',
  'type' => 'customtext',
  'capability' => 'edit_theme_options',
  'transport' => 'refresh',
  'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Custom_Post_Type_Info( $wp_customize, 'ngo_charity_go_to_give_form', array(
  'label' => esc_attr__( 'Go to Give form Page', 'social-charity-pro' ),
  'section' => 'ngo_charity_frontpage_our_causes_section',
  'settings' => 'ngo_charity_go_to_give_form',
  'link'    => 'give_forms',
  'extra' => esc_attr__( ' for more info', 'social-charity-pro' )
) ) 
);
endif;
/*----------------------------------------------------------------------------------------------------------------------------------------*/
/**
 * Front page who we are section
 *
 * @since 1.0.0
 */

$wp_customize->add_section(
  'ngo_charity_frontpage_who_we_are_section',
  array(
    'priority'       => 4,
    'panel'          => 'ngo_charity_frontpage_settings_panel',
    'capability'     => 'edit_theme_options',
    'theme_supports' => '',
    'title'          => __( 'Who We Are Section', 'social-charity-pro' ),
    'description'    => __( 'Managed the who we are display at Frontpage section.', 'social-charity-pro' ),
  )
);

/**
 * Enable/Disable for who we are
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
  'ngo_charity_who_we_are_enable',
  array(
    'default'           => 0,
    'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
  )
);

$wp_customize->add_control(
  'ngo_charity_who_we_are_enable',
  array(
    'section'     => 'ngo_charity_frontpage_who_we_are_section',
    'label'       => __( 'Enable/Disable for who we are', 'social-charity-pro' ),
    'type'        => 'checkbox'
  )       
);

/** Who we are title and description with featured image */

$wp_customize->add_setting( 'ngo_charity_who_we_are', array(
  'capability'            => 'edit_theme_options',
  'default'               => '',
  'sanitize_callback'     => 'ngo_charity_sanitize_dropdown_pages'
) );

$wp_customize->add_control('ngo_charity_who_we_are',
  array(
    'label'                 =>  __( 'Select Page for who we are having featured Image', 'social-charity-pro' ),
    'section' => 'ngo_charity_frontpage_who_we_are_section',
    'type'=> 'dropdown-pages',
    'settings' => 'ngo_charity_who_we_are'
  )
);


/*----------------------------------------------------------------------------------------------------------------------------------------*/
/**
 * Front page Upcoming Events section
 *
 * @since 1.0.0
 */

$wp_customize->add_section(
  'ngo_charity_frontpage_events_section',
  array(
    'priority'       => 5,
    'panel'          => 'ngo_charity_frontpage_settings_panel',
    'capability'     => 'edit_theme_options',
    'theme_supports' => '',
    'title'          => __( 'Events Section', 'social-charity-pro' ),
    'description'    => __( 'Managed the  Events display at Frontpage section.', 'social-charity-pro' ),
  )
);

/**
 * Enable/Disable for  Events
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
  'ngo_charity_events_enable',
  array(
    'default'           => 0,
    'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
  )
);

$wp_customize->add_control(
  'ngo_charity_events_enable',
  array(
    'section'     => 'ngo_charity_frontpage_events_section',
    'label'       => __( 'Enable/Disable for Events', 'social-charity-pro' ),
    'type'        => 'checkbox'
  )       
);


/** Our Events Text */
$wp_customize->add_setting(
  'ngo_charity_events_text',
  array(
    'default'           => __( 'Our Events', 'social-charity-pro' ),
    'sanitize_callback' => 'sanitize_text_field',
    'transport'         => 'postMessage'
  )
);

$wp_customize->add_control(
  'ngo_charity_events_text',
  array(
    'label'    => __( 'Events Heading', 'social-charity-pro' ),
    'section'  => 'ngo_charity_frontpage_events_section',
    'type'     => 'text',
  )
);

$wp_customize->selective_refresh->add_partial( 'ngo_charity_events_text', array(
  'selector' => '.events main-title h2',
  'render_callback' => 'ngo_charity_get_events_text',
) );


$wp_customize->add_setting('event_post_type_info', array(
  'default' => '',
  'type' => 'customtext',
  'capability' => 'edit_theme_options',
  'transport' => 'refresh',
  'sanitize_callback' => 'sanitize_text_field',
) );
$wp_customize->add_control( new Custom_Post_Type_Info( $wp_customize, 'event_post_type_info', array(
  'label' => esc_attr__( 'Go to Event Page', 'social-charity-pro' ),
  'section' => 'ngo_charity_frontpage_events_section',
  'settings' => 'event_post_type_info',
  'link'    => 'event',
  'extra' => esc_attr__( ' for more info', 'social-charity-pro' )
) ) 
);


/*----------------------------------------------------------------------------------------------------------------------------------------*/
/**
 * Front page Volunteer section
 *
 * @since 1.0.0
 */

$wp_customize->add_section(
  'ngo_charity_frontpage_volunteer_section',
  array(
    'priority'       => 6,
    'panel'          => 'ngo_charity_frontpage_settings_panel',
    'capability'     => 'edit_theme_options',
    'theme_supports' => '',
    'title'          => __( 'Volunteer Section', 'social-charity-pro' ),
    'description'    => __( 'Managed the Volunteer display at Frontpage section.', 'social-charity-pro' ),
  )
);

/**
 * Enable/Disable for Volunteer
 *
 * @since 1.0.0
 */

$wp_customize->add_setting( 'ngo_charity_volunteer_s_enable', array(
  'capability'            => 'edit_theme_options',
  'default'               => 0,
  'sanitize_callback'     => 'ngo_charity_sanitize_checkbox'
) );

$wp_customize->add_control('ngo_charity_volunteer_s_enable',
  array(
    'label'   =>  __( 'Enable/Disable for Volunteer', 'social-charity-pro'  ),
    'section' => 'ngo_charity_frontpage_volunteer_section',
    'type'=> 'checkbox',
    'settings' => 'ngo_charity_volunteer_s_enable'
  )
);



/** Volunteer title and description with featured image */

$wp_customize->add_setting( 'ngo_charity_volunteer', array(
  'capability'            => 'edit_theme_options',
  'default'               => '',
  'sanitize_callback'     => 'ngo_charity_sanitize_dropdown_pages'
) );

$wp_customize->add_control('ngo_charity_volunteer',
  array(
    'label'                 =>  __( 'Select Page for Volunteer', 'social-charity-pro'  ),
    'section' => 'ngo_charity_frontpage_volunteer_section',
    'type'=> 'dropdown-pages',
    'settings' => 'ngo_charity_volunteer'
  )
);


/*----------------------------------------------------------------------------------------------------------------------------------------*/
/**
 * Front page Newsletter section
 *
 * @since 1.0.0
 */

$wp_customize->add_section(
  'ngo_charity_frontpage_newsletter_section',
  array(
    'priority'       => 7,
    'panel'          => 'ngo_charity_frontpage_settings_panel',
    'capability'     => 'edit_theme_options',
    'theme_supports' => '',
    'title'          => __( 'Newsletter Section', 'social-charity-pro' ),
    'description'    => __( 'Managed the Newsletter display at Frontpage section.', 'social-charity-pro' ),
  )
);

/**
 * Enable/Disable for Newsletter
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
  'ngo_charity_volunteer_newsletter_enable',
  array(
    'default'           => 0,
    'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
  )
);

$wp_customize->add_control(
  'ngo_charity_volunteer_newsletter_enable',
  array(
    'section'     => 'ngo_charity_frontpage_newsletter_section',
    'label'       => __( 'Enable/Disable for Newsletter', 'social-charity-pro' ),
    'type'        => 'checkbox'
  )       
);

// Newsletter Title
$wp_customize->add_setting('ngo_charity_newsletter_quote',array(
  'default'       =>      '',
  'sanitize_callback'     =>  'sanitize_text_field'
));

$wp_customize->add_control('ngo_charity_newsletter_quote',array(
  'section'       =>      'ngo_charity_frontpage_newsletter_section',
  'label'         =>      __('Newsletter Title', 'social-charity-pro'),
  'description'   =>      __('Eg:- Want to join us?', 'social-charity-pro'),
  'type'          =>      'text',
  'settings'    =>    'ngo_charity_newsletter_quote'
));


// Newsletter Form Shortcode Descriptions
$wp_customize->add_setting('ngo_charity_f_newsletter_shortcode',array(
  'default'       =>      '',
  'sanitize_callback'     =>  'sanitize_text_field'
));
$wp_customize->add_control('ngo_charity_f_newsletter_shortcode',array(
  'section'       =>      'ngo_charity_frontpage_newsletter_section',
  'label'                 =>  __( 'News Letter Section Use Shortcode', 'social-charity-pro' ),
  /* translators: %s: Description */ 
  'description'           => sprintf( __( 'Use Newsletter Plugins shortcode: Eg: %1$s. %2$s See more here %3$s', 'social-charity-pro' ), '[newsletter_form]','<a href="'.esc_url('https://wordpress.org/plugins/newsletter/').'" target="_blank">','</a>' ),
  'type'          =>      'text',
  'settings'    =>    'ngo_charity_f_newsletter_shortcode'
));

/*----------------------------------------------------------------------------------------------------------------------------------------*/
/**
 * Front page Testimonials section
 *
 * @since 1.0.0
 */

$wp_customize->add_section(
  'ngo_charity_frontpage_testimonials_section',
  array(
    'priority'       => 8,
    'panel'          => 'ngo_charity_frontpage_settings_panel',
    'capability'     => 'edit_theme_options',
    'theme_supports' => '',
    'title'          => __( 'Testimonials Section', 'social-charity-pro' ),
    'description'    => __( 'Managed the  Testimonials display at Frontpage section.', 'social-charity-pro' ),
  )
);

/**
 * Enable/Disable for Testimonials
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
  'ngo_charity_testimonials_enable',
  array(
    'default'           => 0,
    'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
  )
);

$wp_customize->add_control(
  'ngo_charity_testimonials_enable',
  array(
    'section'     => 'ngo_charity_frontpage_testimonials_section',
    'label'       => __( 'Enable/Disable for Testimonials', 'social-charity-pro' ),
    'type'        => 'checkbox'
  )       
);

/** Testimonials Text */
$wp_customize->add_setting(
  'ngo_charity_tetimonials_text',
  array(
    'default'           => __( 'What People Say', 'social-charity-pro' ),
    'sanitize_callback' => 'sanitize_text_field',
    'transport'         => 'postMessage'
  )
);

$wp_customize->add_control(
  'ngo_charity_tetimonials_text',
  array(
    'label'    => __( 'Testimonials Heading', 'social-charity-pro' ),
    'section'  => 'ngo_charity_frontpage_testimonials_section',
    'type'     => 'text',
  )
);

$wp_customize->selective_refresh->add_partial( 'ngo_charity_tetimonials_text', array(
  'selector' => '.testimonial main-title h2',
  'render_callback' => 'ngo_charity_get_testimonials_text',
) );


$wp_customize->add_setting('testimonial_post_type_info', array(
  'default' => '',
  'type' => 'customtext',
  'capability' => 'edit_theme_options',
  'transport' => 'refresh',
  'sanitize_callback' => 'sanitize_text_field',
) );
$wp_customize->add_control( new Custom_Post_Type_Info( $wp_customize, 'testimonial_post_type_info', array(
  'label' => esc_attr__( 'Go to Testimonials Page', 'social-charity-pro' ),
  'section' => 'ngo_charity_frontpage_testimonials_section',
  'settings' => 'testimonial_post_type_info',
  'link'    => 'testimonial',
  'extra' => esc_attr__( ' for more info', 'social-charity-pro' )
) ) 
);

/*----------------------------------------------------------------------------------------------------------------------------------------*/
/**
 * Front page Gallery section
 *
 * @since 1.0.0
 */

$wp_customize->add_section(
  'ngo_charity_frontpage_gallery_section',
  array(
    'priority'       => 9,
    'panel'          => 'ngo_charity_frontpage_settings_panel',
    'capability'     => 'edit_theme_options',
    'theme_supports' => '',
    'title'          => __( 'Gallery Section', 'social-charity-pro' ),
    'description'    => __( 'Managed the  Gallery display at Frontpage section.', 'social-charity-pro' ),
  )
);

/**
 * Enable/Disable for Gallery
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
  'ngo_charity_gallery_enable',
  array(
    'default'           => 0,
    'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
  )
);

$wp_customize->add_control(
  'ngo_charity_gallery_enable',
  array(
    'section'     => 'ngo_charity_frontpage_gallery_section',
    'label'       => __( 'Enable/Disable for Gallery', 'social-charity-pro' ),
    'type'        => 'checkbox'
  )       
);

/** Gallery Text */
$wp_customize->add_setting(
  'ngo_charity_gallery_text',
  array(
    'default'           => __( 'Our Gallery', 'social-charity-pro' ),
    'sanitize_callback' => 'sanitize_text_field',
    'transport'         => 'postMessage'
  )
);

$wp_customize->add_control(
  'ngo_charity_gallery_text',
  array(
    'label'    => __( 'Gallery Heading', 'social-charity-pro' ),
    'section'  => 'ngo_charity_frontpage_gallery_section',
    'type'     => 'text',
  )
);

$wp_customize->selective_refresh->add_partial( 'ngo_charity_gallery_text', array(
  'selector' => '.gallery main-title h2',
  'render_callback' => 'ngo_charity_get_gallery_text',
) );


$wp_customize->add_setting('gallery_post_type_info', array(
  'default' => '',
  'type' => 'customtext',
  'capability' => 'edit_theme_options',
  'transport' => 'refresh',
  'sanitize_callback' => 'sanitize_text_field',
) );
$wp_customize->add_control( new Custom_Post_Type_Info( $wp_customize, 'gallery_post_type_info', array(
  'label' => esc_attr__( 'Go to Gallery Page', 'social-charity-pro' ),
  'section' => 'ngo_charity_frontpage_gallery_section',
  'settings' => 'gallery_post_type_info',
  'link'    => 'gallery',
  'extra' => esc_attr__( ' for more info', 'social-charity-pro' )
) ) 
);

/*----------------------------------------------------------------------------------------------------------------------------------------*/
/**
 * Front page blog section
 *
 * @since 1.0.0
 */

$wp_customize->add_section(
  'ngo_charity_frontpage_blog_section',
  array(
    'priority'       => 10,
    'panel'          => 'ngo_charity_frontpage_settings_panel',
    'capability'     => 'edit_theme_options',
    'theme_supports' => '',
    'title'          => __( 'Blog Section', 'social-charity-pro' ),
    'description'    => __( 'Managed the  Blog display at Frontpage section.', 'social-charity-pro' ),
  )
);

/**
 * Enable/Disable for Blog Section
 *
 * @since 1.0.0
 */
$wp_customize->add_setting(
  'ngo_charity_blog_enable',
  array(
    'default'           => 1,
    'sanitize_callback' => 'ngo_charity_sanitize_checkbox',
  )
);

$wp_customize->add_control(
  'ngo_charity_blog_enable',
  array(
    'section'     => 'ngo_charity_frontpage_blog_section',
    'label'       => __( 'Enable/Disable for Blog', 'social-charity-pro' ),
    'type'        => 'checkbox'
  )       
);


/** Blogs Text */
$wp_customize->add_setting(
  'ngo_charity_blog_text',
  array(
    'default'           => __( 'Latest Blog', 'social-charity-pro' ),
    'sanitize_callback' => 'sanitize_text_field',
    'transport'         => 'postMessage'
  )
);

$wp_customize->add_control(
  'ngo_charity_blog_text',
  array(
    'label'    => __( 'Blog Heading', 'social-charity-pro' ),
    'section'  => 'ngo_charity_frontpage_blog_section',
    'type'     => 'text',
  )
);

$wp_customize->selective_refresh->add_partial( 'ngo_charity_blog_text', array(
  'selector' => '.blog main-title h2',
  'render_callback' => 'ngo_charity_get_blog_text',
) );
//Category select for blogs
$wp_customize->add_setting('ngo_charity_blog_category_id',array(
  'capability'        => 'edit_theme_options',
  'sanitize_callback' => 'ngo_charity_sanitize_category',
  'default' =>  '1',
)
);

$wp_customize->add_control(new Social_Charity_Customize_Dropdown_Taxonomies_Control($wp_customize,'ngo_charity_blog_category_id',
  array(
   'label' => __('Select Category for Blog','social-charity-pro'),
   'section' => 'ngo_charity_frontpage_blog_section',
   'settings' => 'ngo_charity_blog_category_id',
   'type'=> 'dropdown-taxonomies',
 )
));

$wp_customize->add_setting( 'ngo_charity_blog_number', array(
  'capability'            => 'edit_theme_options',
  'default'               => '3',
  'sanitize_callback'     => 'absint'
));

$wp_customize->add_control( 'ngo_charity_blog_number', array(
  'label'                 =>  __( 'Number of Recent Blogs to Show in Front Page', 'social-charity-pro' ),
  'description'           =>  __( 'input 3,4,5,6,7,8,9,10', 'social-charity-pro' ),
  'section'               => 'ngo_charity_frontpage_blog_section',
  'type'                  => 'number',
  'settings' => 'ngo_charity_blog_number',
) );
}