<?php
remove_action( 'give_single_form_summary', 'give_template_single_title', 5 );
/**
 * NGO Charity functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Social_Charity
 */

if ( ! function_exists( 'social_charity_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function social_charity_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on NGO Charity, use a find and replace
		 * to change 'social-charity-pro' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'social-charity-pro', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'social-charity-banner-1135*666', 1135, 666, true );
		add_image_size( 'social-charity-causes-image', false, 214, true );
		add_image_size( 'social-charity-who-we-are-image', false, 337, true );
		add_image_size( 'social-charity-events-image', false, 174, true );
		add_image_size( 'social-charity-testimonials-image', 117, 117, true );
		add_image_size( 'social-charity-gallery-image', false, 170, true );
		add_image_size( 'social-charity-blog-image', false, 209, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'social-charity-pro' ),
			'quick-links' => esc_html__('Footer(Quick Links)','social-charity-pro')
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'social_charity_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'social_charity_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function social_charity_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'social_charity_content_width', 640 );
}
add_action( 'after_setup_theme', 'social_charity_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function social_charity_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'social-charity-pro' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'social-charity-pro' ),
		'before_widget' => '<div id="%1$s" class=" block widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="title widget-title">',
		'after_title'   => '</h4>',
	) );


	register_sidebar( array(
		'name'          => esc_html__( 'Footer widget 1', 'social-charity-pro' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'social-charity-pro' ),
		'before_widget' => '<div id="%1$s" class="f-about widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '',
		'after_title'   => '',
	) );


	register_sidebar( array(
		'name'          => esc_html__( 'Footer widget 2', 'social-charity-pro' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here.', 'social-charity-pro' ),
		'before_widget' => '<div id="%1$s" class="quick-links widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="f-title widget-title">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer widget 3', 'social-charity-pro' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here.', 'social-charity-pro' ),
		'before_widget' => '<div id="%1$s" class="recent-news widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="f-title widget-title">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer widget 4', 'social-charity-pro' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'Add widgets here.', 'social-charity-pro' ),
		'before_widget' => '<div id="%1$s" class="contact-form widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="f-title widget-title">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => __( 'Google map iframe', 'social-charity-pro' ),
		'id'            => 'google-map',
		'description'   => __( 'Add widgets here.', 'social-charity-pro' ),
		'before_widget' => '',
		'after_widget'  => '',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'social_charity_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
require get_template_directory(). '/inc/enqueue.php';


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';


/**
 * Bootstrap Navwalker
 */
require get_template_directory() . '/inc/wp-bootstrap-navwalker.php';


require get_template_directory() . '/inc/customizer/customizer-partials-function.php';


require_once get_template_directory() . '/inc/breadcrumbs.php';


// Service Custom Post Type
require get_template_directory() . '/inc/cpt/service.php';

// Testimonial Custom Post Type
require get_template_directory() . '/inc/cpt/testimonial.php';

// Gallery Custom Post Type
require get_template_directory() . '/inc/cpt/gallery.php';

// Event Custom Post Type
require get_template_directory() . '/inc/cpt/event.php';


/*Bootstrap Pagination Function*/

function social_charity_portfolio_bs_pagination($pages = '', $range = 4)
{  
	$showitems = ($range * 2) + 1;  
	$paged = get_query_var( 'paged');

	if(empty($paged)) $paged = 1;
	if($pages == '')
	{
		global $wp_query; 
		$pages = $wp_query->max_num_pages;
		if(!$pages)
		{
			$pages = 1;
		}
	}   

	if(1 != $pages)
	{
		echo '<ul class="pagination">';
		for ($i=1; $i <= $pages; $i++)
		{
			if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
			{
				echo ($paged == $i)? "<li class=\"page-item active\"><a href='".esc_url(get_pagenum_link($i))."' class='page-link'>".esc_html($i)."</a></li>":"<li class='page-item'><a href='".esc_url(get_pagenum_link($i))."' class='page-link'>".esc_html($i)."</a></li>";
			}
		}

		if ($paged < $pages ) echo "<li class='page-item next'><a href=\"".esc_url(get_pagenum_link($paged + 1))."\" class='page-link'>".esc_html__('Next Page','social-charity-pro')."</a></li>";  
		echo "</ul>";
	}
}

function social_charity_get_related_posts( $taxonomy = '', $args = array() )
{ 
	if ( !is_single() )
		return false;

	if ( !$taxonomy ) 
		return false;

	$taxonomy = filter_var( $taxonomy, FILTER_SANITIZE_STRING );
	if ( !taxonomy_exists( $taxonomy ) )
		return false;

	$current_post = get_queried_object();

	$terms = wp_get_post_terms( $current_post->ID, $taxonomy, array( 'fields' => 'ids') );

	if ( !$terms || is_wp_error( $terms ) )
		return false;

	$defaults = array(
		'post_type' => $current_post->post_type,
		'post__not_in' => array( $current_post->ID),
		'tax_query' => array(
			array(
				'taxonomy' => $taxonomy,
				'terms' => $terms,
				'include_children' => false
			),
		),
	);

	if ( is_array( $args ) ) {
		$args = wp_parse_args( $args, $defaults );
	} else {
		$args = $defaults;
	}

	$q = get_posts( $args );

	return $q;
}

/*social sharing*/
function social_charity_social_sharing_buttons($content) {
	global $post;
	if(is_singular() || is_home()){

		// Get current page URL 
		$ourBlogURL = urlencode(get_permalink());

		// Get current page title
		$ourBlogTitle = htmlspecialchars(urlencode(html_entity_decode(get_the_title(), ENT_COMPAT, 'UTF-8')), ENT_COMPAT, 'UTF-8');
		// $ourBlogTitle = str_replace( ' ', '%20', get_the_title());
		
		// Get Post Thumbnail for pinterest
		$ourBlogThumbnail = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );

		// Construct sharing URL without using any script
		$twitterURL = 'https://twitter.com/intent/tweet?text='.$ourBlogTitle.'&amp;url='.$ourBlogURL.'&amp;via=PawanDongol';
		$facebookURL = 'https://www.facebook.com/sharer/sharer.php?u='.$ourBlogURL;
		$linkedInURL = 'https://www.linkedin.com/shareArticle?mini=true&url='.$ourBlogURL.'&amp;title='.$ourBlogTitle;
		// Based on popular demand added Pinterest too
	
		// Add sharing button at the end of page/page content
		$content .= '<div class="share-holder"><ul class="share">';
		$content .= '<span class="title">Share:</span> ';
		$content .='<li><a href="'. $facebookURL .'" target="_blank"><span class="fa fa-facebook" aria-hidden="true"></span></a></li>';
		$content .='<li><a href="'. $twitterURL .'" target="_blank"><span class="fa fa-twitter" aria-hidden="true"></span></a></li>';
		
		$content .='<li><a href="'. $linkedInURL .'" target="_blank"><span class="fa fa-linkedin" aria-hidden="true"></span></a></li>';
		$content .= '</ul></div>';
		
		return $content;
	}else{
		// if not a post/page then don't include sharing button
		return $content;
	}
};

function social_charity_register_reording_theme_options() {
	register_setting( 'reordering-settings-group', 'filter_fields_order' );
}
add_action( 'admin_init', 'social_charity_register_reording_theme_options' );

function hash_frontpage_array()
{
	$fields_order_default = array(
		0 => array(
			'id' => '1',
			'name' => 'Service Section',
			'slug' => 'services'
		),
		1 => array(
			'id' => '1',
			'name' => 'Causes section',
			'slug' => 'causes'
		),

		2 => array(
			'id' => '2',
			'name' => 'About Section',
			'slug' => 'about'
		),
		3 => array(
			'id' => '3',
			'name' => 'Events Section',
			'slug' => 'events'
		),

		4 => array(
			'id' => '4',
			'name' => 'Volunteer Section',
			'slug' => 'volunteer'
		),
		5 => array(
			'id' => '5',
			'name' => 'Testimonials Section',
			'slug' => 'testimonial'
		),
		6 => array(
			'id' => '6',
			'name' => 'Gallery Section',
			'slug' => 'gallery'
		),
		7 => array(
			'id' => '7',
			'name' => 'Blog Section',
			'slug' => 'blog'
		)
	);

	return $fields_order_default;
}
add_filter( 'the_content', 'social_charity_social_sharing_buttons');
if ( is_admin() ) {
	// Load about.
	
	require_once trailingslashit( get_template_directory() ) . 'inc/theme-info/class-about.php';
	require_once trailingslashit( get_template_directory() ) . 'inc/theme-info/about.php';

	// Load demo.
	require_once trailingslashit( get_template_directory() ) . 'inc/demo/class-demo.php';
	require_once trailingslashit( get_template_directory() ) . 'inc/demo/demo.php';
}

function check_wp_give_plugin_activation()
{
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	return is_plugin_active( 'give/give.php' );
}


/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}


