<?php
/**
 * Define customizer custom classes
 *
 * @package Social_Charity
 * @since 1.0.0
 */
/*----------------------------------------------------------------------------------------------------------------------------------------*/
/**
 * Switch button customize control.
 *
 * @since 1.0.3
 * @access public
 */
if( class_exists( 'WP_Customize_Control' ) ) {

/**
 * Class Social_Charity_Customize_Dropdown_Taxonomies_Control
 */
class Social_Charity_Customize_Dropdown_Taxonomies_Control extends WP_Customize_Control {

  public $type = 'dropdown-taxonomies';

  public $taxonomy = '';

  public function __construct( $manager, $id, $args = array() ) {

    $our_taxonomy = 'category';
    if ( isset( $args['taxonomy'] ) ) {
      $taxonomy_exist = taxonomy_exists( esc_attr( $args['taxonomy'] ) );
      if ( true === $taxonomy_exist ) {
        $our_taxonomy = esc_attr( $args['taxonomy'] );
      }
    }
    $args['taxonomy'] = $our_taxonomy;
    $this->taxonomy = esc_attr( $our_taxonomy );

    parent::__construct( $manager, $id, $args );
  }

  public function render_content() {

    $tax_args = array(
      'hierarchical' => 1,
      'taxonomy'     => $this->taxonomy,
    );
    $all_taxonomies = get_categories( $tax_args );

    ?>
    <label>
      <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
      <select <?php echo esc_attr($this->link()); ?>>
        <?php
        printf('<option value="%s" %s>%s</option>', '', selected(esc_attr($this->value()), '', false),esc_html('Select', 'social-charity-pro') );
        ?>
        <?php if ( ! empty( $all_taxonomies ) ): ?>
          <?php foreach ( $all_taxonomies as $key => $tax ): ?>
            <?php
            printf('<option value="%s" %s>%s</option>',esc_attr( $tax->term_id ), selected($this->value(), esc_attr( $tax->term_id ), false), esc_attr( $tax->name ) );
            ?>
          <?php endforeach ?>
        <?php endif ?>
      </select>

    </label>
    <?php
  }

}

// Educational reordering sectioon
class Social_Charity_FrontPage_Reordering_Customize extends WP_Customize_Control {
  public $type = 'customtext';
      public $extra = ''; // we add this for the extra description
      public function render_content() {
        ?>
        <form method="post"  id="theme-options-form">
          <?php settings_fields( 'reordering-settings-group' ); ?>
          <?php do_settings_sections( 'reordering-settings-group' ); ?>
          <div class="admin-module"> 
            <ul class="filter-fields-list">
              <?php 
              $filter_fields_order = get_option('filter_fields_order',hash_frontpage_array()); 
              foreach($filter_fields_order as $value) { ?>

                <?php
                if(isset($value['id'])) { $id = $value['id']; }
                if(isset($value['name'])) { $name = $value['name']; }
                if(isset($value['slug'])) { $slug = $value['slug']; }
                ?>

                <li class="sortable-item">
                 <i class="fa fa-eye"></i> <?php echo $name; ?>
                 <input type="hidden" name="filter_fields_order[<?php echo absint( $id ); ?>][id]" value="<?php echo absint( $id ); ?>" />
                 <input type="hidden" name="filter_fields_order[<?php echo absint( $id ); ?>][name]" value="<?php echo esc_attr($name); ?>" />
                 <input type="hidden" name="filter_fields_order[<?php echo absint( $id ); ?>][slug]" value="<?php echo esc_attr($slug); ?>" />
               </li>
             <?php } ?>
           </ul>
         </div>
       </form>
     <?php   }
   } //End Educational reordering section

    // Setting: Custom Post type Linkss.
   class Custom_Post_Type_Info extends WP_Customize_Control {
    public $type = 'customtext';
    public $extra = ''; // we add this for the extra description
    public $link = '';
    public function render_content() {
      ?>
      <label>            
        <a href="<?php echo esc_url( 'edit.php?post_type='.$this->link ); ?>" target='_blank'><?php echo esc_html( $this->label ); ?></a>
        <span><?php echo esc_html( $this->extra ); ?></span>         
      </label>
      <?php
    }
  }
}


